## Copyright 2018 Augusta University
##
## Licensed under the Apache License, Version 2.0 (the "License");
## you may not use this file except in compliance with the License.
## You may obtain a copy of the License at
##
##    http://www.apache.org/licenses/LICENSE-2.0
##
## Unless required by applicable law or agreed to in writing, software
## distributed under the License is distributed on an "AS IS" BASIS,
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and
## limitations under the License.
include:
  - /formulas/common/sysctl

{% set type = opts.id.split('-')[0] %}
{% set role = salt['pillar.get']('hosts:'+type+':role', type) %}

initial_module_sync:
  saltutil.sync_all:
    - refresh: True
    - unless:
      - fun: grains.has_value
        key: build_phase

build_phase:
  grains.present:
    - value: base
    - unless:
      - fun: grains.has_value
        key: build_phase

type:
  grains.present:
    - value: {{ type }}

role:
  grains.present:
    - value: {{ role }}

{{ pillar['timezone'] }}:
  timezone.system:
    - utc: True

{% for key in pillar['authorized_keys'] %}
{{ key }}:
  ssh_auth.present:
    - user: root
    - enc: {{ pillar['authorized_keys'][ key ]['encoding'] }}
{% endfor %}

{% if opts.id not in ['salt', 'pxe'] %}
hosts_name_resolution:
  host.present:
    - ip: {{ salt['network.ipaddrs'](cidr=pillar['networking']['subnets']['management'])[0] }}
    - names:
      - {{ grains['id'] }}
      - {{ grains['host'] }}
    - clean: true
{% endif %}

/etc/rsyslog.d/10-syslog.conf:
  file.managed:
    - source: salt://formulas/common/syslog/files/10-syslog.conf
    - template: jinja
    - defaults:
{% if salt['pillar.get']('syslog_url', False) != False %}
        logger: {{ pillar['syslog_url'] }}
{% else %}
        logger: 127.0.0.1:5514
{% endif %}
{% if salt['pillar.get']('syslog_url', False) == False %}
  {% for host, addresses in salt['mine.get']('role:graylog', 'network.ip_addrs', tgt_type='grain') | dictsort() %}
    {% for address in addresses %}
      {% if salt['network']['ip_in_subnet'](address, pillar['networking']['subnets']['management']) %}
    - context:
        logger: {{ address }}:5514
      {% endif %}
    {% endfor %}
  {% endfor %}
{% endif %}

{% if salt['pillar.get']('infra:ldap_enabled', False) == True %}
/etc/ssh/sshd_config:
  file.managed:
    - source: salt://formulas/common/sshd/files/sshd_config

{% if grains['virtual'] == "physical" %}

upload_epel_repo:
  file.managed:
    - name: /etc/yum.repos.d/repo-setup.sh
    - source: salt://formulas/common/epel/repo-setup.sh
    - user: root
    - group: root
    - mode: "0700"

upload_elrepo_repo:
  file.managed:
    - name: /etc/yum.repos.d/kernel-setup.sh
    - source:  salt://formulas/common/kernel/files/kernel-setup.sh
    - user: root
    - group: root
    - mode: "0700"

configure_epel_script:
  cmd.script:
    - name: /etc/yum.repos.d/repo-setup.sh
    - shell: /bin/bash
    - user: root
    - require:
      - file: upload_epel_repo

install_kernel_script:
  cmd.script:
    - name: /etc/yum.repos.d/kernel-setup.sh
    - shell: /bin/bash
    - user: root
    - require:
      - file: upload_elrepo_repo

dnf_update:
  cmd.run:
    - name: >
        if rpm -q docker-ce && rpm -q thrift; then
          dnf update --exclude docker-ce,thrift -y
        elif rpm -q docker-ce; then
          dnf update --exclude docker-ce -y
        elif rpm -q thrift; then
          dnf update --exclude thrift -y
        else
          dnf update -y
        fi
    - shell: /bin/bash
    - user: root

#set_latest_kernel_as_default:
#  cmd.run:
#    - name: |
#        latest_kernel=$(ls -t /boot/vmlinuz-* | grep -v rescue | head -1 | awk -F'/' '{print $3}')
#        grubby --set-default "/boot/$latest_kernel"
#    - shell: /bin/bash
#    - user: root

pyghmi_pip:
  pip.installed:
    - name: pyghmi
  pkg.installed:
    - pkgs:
      - ipmitool
      - vim-enhanced

#enable_fips:
#  cmd.run:
#    - name: |
#        if [[ $(fips-mode-setup --check) != "FIPS mode is enabled." ]]; then
#          fips-mode-setup --enable
#        fi
#    - shell: /bin/bash
#    - user: root

{% endif %}

{% if role != 'arm' %}

/etc/udev/rules.d/60-netdev.rules:
  file.managed:
    - user: root
    - group: root
    - mode: '0600'
    - source: salt://formulas/common/kernel/files/60-netdev.rules

{% endif %}

# The LDAP server is not controlled under this project. Pointing to the source so if it ever changes this will still work
/usr/local/share/ca-certificates/ipa.cybbh.space/ldap_ca.crt:
  file.managed:
    - source: https://git.cybbh.space/vta/saltstack/raw/master/apps/public/ipa/files/ipa_ca.crt
    - source_hash: https://git.cybbh.space/vta/saltstack/raw/master/apps/public/ipa/files/hash
    - makedirs: True
    - mode: '0644'

update-ca-certificates-ldap:
  cmd.run:
    - name: update-ca-trust
    - onchanges:
      - file: /usr/local/share/ca-certificates/ipa.cybbh.space/ldap_ca.crt

sshd_service:
  service.running:
    - name: sshd
    - watch:
      - /etc/ssh/sshd_config

{% endif %}
