## Copyright 2018 Augusta University
##
## Licensed under the Apache License, Version 2.0 (the "License");
## you may not use this file except in compliance with the License.
## You may obtain a copy of the License at
##
##    http://www.apache.org/licenses/LICENSE-2.0
##
## Unless required by applicable law or agreed to in writing, software
## distributed under the License is distributed on an "AS IS" BASIS,
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and
## limitations under the License.

include:
  - /formulas/{{ grains['role'] }}/install

{% set type = opts.id.split('-')[0] %}
{% set role = salt['pillar.get']('hosts:'+type+':role', type) %}

{% import 'formulas/common/macros/constructor.sls' as constructor with context %}

### Calculate public interface - this is referenced a few times
### Potential to make 'interface calculator' macro
{% if salt['pillar.get']('hosts:'+grains['type']+':networks:public:bridge', False) == True %}
  {% set public_interface = 'public_br' %}
{% elif salt['pillar.get']('hosts:'+grains['type']+':networks:public:interfaces') | length > 1 %}
  {% set public_interface = 'public_bond' %}
{% else %}
  {% set public_interface = pillar['hosts'][grains['type']]['networks']['public']['interfaces'][0] %}
{% endif %}

/etc/udev/rules.d/59-net.ring.rules:
  file.managed:
    - user: root
    - group: root
    - mode: '0600'
    - source: salt://formulas/compute/files/59-net.ring.rules

udevadm trigger:
  cmd.run:
    - onchanges:
      - file: /etc/udev/rules.d/60-netdev.rules
      - file: /etc/udev/rules.d/59-net.ring.rules

append_new_grub_cmdline:
  cmd.run:
    - name: grubby --update-kernel=ALL --args="{{ pillar['hosts'][grains['type']]['kernel_param'][0] }}"
    - unless: grep "{{ pillar['hosts'][grains['type']]['kernel_param'][0] }}" /proc/cmdline

update_grub_configuration:
  cmd.wait:
    - name: grub2-mkconfig -o /boot/efi/EFI/rocky/grub.cfg
    - watch:
      - cmd: append_new_grub_cmdline
