## Copyright 2020 Augusta University
##
## Licensed under the Apache License, Version 2.0 (the "License");
## you may not use this file except in compliance with the License.
## You may obtain a copy of the License at
##
##    http://www.apache.org/licenses/LICENSE-2.0
##
## Unless required by applicable law or agreed to in writing, software
## distributed under the License is distributed on an "AS IS" BASIS,
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and
## limitations under the License.

#!/usr/bin/env python

from html import escape
from urllib.parse import parse_qs

body = """\
#!ipxe

set try:int32 0

:retry_loop iseq ${try} 4 && goto bootstrap_failure ||
## for some reason, the retcode on kernel and initrd is detected
## as a failure no matter what.  Will only retry on a failed boot
imgfree
%(kernel)s ||
%(initrd)s ||
boot || sleep 5 && inc try && echo Failed to boot on try ${try}... && goto retry_loop

:bootstrap_failure
shell
"""

def application (environ, start_response):

    d = parse_qs(environ['QUERY_STRING'])
    uuid = d.get('uuid', [''])[0]
    uuid = escape(uuid)
    host_data = open("/var/www/html/assignments/"+uuid.upper(), "r")
    host_type = host_data.readline().strip()
    hostname_assignment = host_data.readline().strip()
    os_assignment = host_data.readline().strip()
    interface = host_data.readline().strip()

    if os_assignment == "rocky9.3":
        response_body = body % {
            'kernel': "kernel http://download.rockylinux.org/pub/rocky/9/BaseOS/x86_64/kickstart/images/pxeboot/vmlinuz inst.ks=http://{{ pxe_record }}/configs/"+host_type+" inst.lang=en_US inst.keymap=us ip=::::"+hostname_assignment+":"+interface+":dhcp initrd=initrd.img",
            'initrd': "initrd http://download.rockylinux.org/pub/rocky/9/BaseOS/x86_64/kickstart/images/pxeboot/initrd.img"
            }
    elif os_assignment == "rocky8":
        response_body = body % {
            'kernel': "kernel http://rockylinux.osuosl.org/8.4/BaseOS/x86_64/kickstart/images/pxeboot/vmlinuz ks=http://{{ pxe_record }}/configs/"+host_type+" lang=en_US keymap=us ip=::::"+hostname_assignment+":"+interface+":dhcp initrd=initrd.img",
            'initrd': "initrd http://rockylinux.osuosl.org/8.4/BaseOS/x86_64/kickstart/images/pxeboot/initrd.img"
            }

    response_body = bytes(response_body, encoding= 'utf-8')
    status = '200 OK'
    response_headers = [
        ('Content-Type', 'text/plain'),
        ('Content-Length', str(len(response_body)))
    ]

    start_response(status, response_headers)
    return [response_body]
