## Copyright 2018 Augusta University
##
## Licensed under the Apache License, Version 2.0 (the "License");
## you may not use this file except in compliance with the License.
## You may obtain a copy of the License at
##
##    http://www.apache.org/licenses/LICENSE-2.0
##
## Unless required by applicable law or agreed to in writing, software
## distributed under the License is distributed on an "AS IS" BASIS,
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and
## limitations under the License.

include:
  - /formulas/{{ grains['role'] }}/install

{% import 'formulas/common/macros/constructor.sls' as constructor with context %}

storage_hosts:
  file.managed:
    - template: jinja
    - defaults:
        storage_hosts: {{ constructor.host_file_constructor(role='storage')|yaml_encode }}
    - names:
      - /etc/hosts:
        - source: salt://formulas/storage/files/hosts

{% if salt['grains.get']('build_phase') == 'install' %}
{% for osd in pillar['osd_mappings'][grains['type']]['osd'] %}
initial_zap_osd_{{ osd }}:
  cmd.run:
    - name: ceph-volume lvm zap --destroy {{ osd }}
{% endfor %}
{% endif %}

/etc/udev/rules.d/59-net.ring.rules:
  file.managed:
    - user: root
    - group: root
    - mode: '0600'
    - source: salt://formulas/storage/files/59-net.ring.rules

udevadm trigger:
  cmd.run:
    - watch:
      - file: /etc/udev/rules.d/60-netdev.rules
      - file: /etc/udev/rules.d/59-net.ring.rules

/root/deploy_rgw.sh:
  file.managed:
    - user: root
    - group: root
    - mode: '0644'
    - source: salt://formulas/storage/files/deploy_rgw.sh

/root/osd_spec.yaml:
  file.managed:
    - user: root
    - group: root
    - mode: '0644'
    - source: salt://formulas/storage/files/osd_spec.yaml

append_new_grub_cmdline:
  cmd.run:
    - name: grubby --update-kernel=ALL --args="{{ pillar['hosts'][grains['type']]['kernel_param'][0] }}"
    - unless: grep "{{ pillar['hosts'][grains['type']]['kernel_param'][0] }}" /proc/cmdline

update_grub_configuration:
  cmd.wait:
    - name: grub2-mkconfig -o /boot/efi/EFI/rocky/grub.cfg
    - watch:
      - cmd: append_new_grub_cmdline
